==> haskell-text-manipulate-0.3.1.0-67-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-text-manipulate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-manipulate
version:              0.3.1.0
visibility:           public
id:                   text-manipulate-0.3.1.0-4Z8wqRDnhoy19y7cYb1q6d
key:                  text-manipulate-0.3.1.0-4Z8wqRDnhoy19y7cYb1q6d
license:              MPL-2.0
copyright:            Copyright (c) 2014-2022 Brendan Hay
maintainer:           Brendan Hay <brendan.g.hay@gmail.com>
author:               Brendan Hay
homepage:             https://github.com/brendanhay/text-manipulate
synopsis:
    Case conversion, word boundary manipulation, and textual subjugation.

description:
    Manipulate identifiers and structurally non-complex pieces
    of text by delimiting word boundaries via a combination of whitespace,
    control-characters, and case-sensitivity.

    Has support for common idioms like casing of programmatic variable names,
    taking, dropping, and splitting by word, and modifying the first character
    of a piece of text.

category:             Data, Text
abi:                  63fa43443c9c47ed4b8fddebc48425bd
exposed:              True
exposed-modules:      Data.Text.Lazy.Manipulate Data.Text.Manipulate
hidden-modules:
    Data.Text.Manipulate.Internal.Fusion
    Data.Text.Manipulate.Internal.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-manipulate-0.3.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-manipulate-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-manipulate
hs-libraries:         HStext-manipulate-0.3.1.0-4Z8wqRDnhoy19y7cYb1q6d
depends:              base-4.16.4.0 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-text-manipulate/html/text-manipulate.haddock

haddock-html:         /usr/share/doc/haskell-text-manipulate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-manipulate-0.3.1.0-95.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-text-manipulate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-manipulate
version:              0.3.1.0
visibility:           public
id:                   text-manipulate-0.3.1.0-D5tnKz3xTmQ4LQrpY9Vq5v
key:                  text-manipulate-0.3.1.0-D5tnKz3xTmQ4LQrpY9Vq5v
license:              MPL-2.0
copyright:            Copyright (c) 2014-2022 Brendan Hay
maintainer:           Brendan Hay <brendan.g.hay@gmail.com>
author:               Brendan Hay
homepage:             https://github.com/brendanhay/text-manipulate
synopsis:
    Case conversion, word boundary manipulation, and textual subjugation.

description:
    Manipulate identifiers and structurally non-complex pieces
    of text by delimiting word boundaries via a combination of whitespace,
    control-characters, and case-sensitivity.

    Has support for common idioms like casing of programmatic variable names,
    taking, dropping, and splitting by word, and modifying the first character
    of a piece of text.

category:             Data, Text
abi:                  d5100418ef4dc2d54f26aa7df7fd0d52
exposed:              True
exposed-modules:      Data.Text.Lazy.Manipulate Data.Text.Manipulate
hidden-modules:
    Data.Text.Manipulate.Internal.Fusion
    Data.Text.Manipulate.Internal.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-manipulate-0.3.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-manipulate-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-manipulate-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-manipulate
hs-libraries:         HStext-manipulate-0.3.1.0-D5tnKz3xTmQ4LQrpY9Vq5v
depends:              base-4.17.2.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-text-manipulate/html/text-manipulate.haddock

haddock-html:         /usr/share/doc/haskell-text-manipulate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
